@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20260119';
+our $VERSION = '5.20260220';
 our %utilities;
 
 sub utilities {
@@ -2224,6 +2224,13 @@ my %delta = (
         removed => {
         }
     },
+    5.043008 => {
+        delta_from => 5.043007,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
